import { Application, IPlugin } from '@phosphor/application';
import { Widget } from '@phosphor/widgets';
/**
 * The example plugin.
 */
declare const examplePlugin: IPlugin<Application<Widget>, void>;
export default examplePlugin;
