#!/usr/bin/env python
# coding: utf-8

"""
This module contains Jupyter widgets for interactively specifying preferences
as well as interactively and non-interactively displaying solutions.
"""

from .widgets import VegaWidget, NimbusPrefWidget, ParplotWidget

__all__ = ['VegaWidget', 'NimbusPrefWidget', 'ParplotWidget']
