#!/usr/bin/env python
# coding: utf-8

version_info = (0, 2, 0)
__version__ = ".".join(map(str, version_info))

# The version of the attribute spec that this package
# implements. This is the value used in
# _model_module_version/_view_module_version.
#
# Update this value when attributes are added/removed from
# your models, or serialized format changes.
EXTENSION_SPEC_VERSION = '1.0.0'
